# -*- coding: utf-8 -*-
"""
aiida_gaussian

AiiDA plugin for the Gaussian quantum chemistry software
"""

from .version import __version__

__all__ = [
    "__version__",
]
